export const indexModel = `
import { Sequelize } from 'sequelize';

const databaseConfig = require('../config/database');
const sequelizeConnection = new Sequelize(databaseConfig)

export default sequelizeConnection;

`

export const userModel = `
import { DataTypes, Model, Optional } from 'sequelize'
import sequelizeConnection from '.';

interface UserAttributes {
  id: number;
  firstName: string;
  lastName: string;
  createdAt?: Date;
  updatedAt?: Date;
}
export interface UserInput extends Optional<UserAttributes, 'id'> { }
export interface UserOuput extends Required<UserAttributes> { }

class User extends Model<UserAttributes, UserInput> implements UserAttributes {
  public id!: number
  public firstName!: string
  public lastName!: string

  public readonly createdAt!: Date;
  public readonly updatedAt!: Date;
}

User.init({
  id: {
    type: DataTypes.INTEGER.UNSIGNED,
    autoIncrement: true,
    primaryKey: true,
  },
  firstName: {
    type: DataTypes.STRING,
    allowNull: false
  },
  lastName: {
    type: DataTypes.STRING,
    allowNull: false
  },
}, {
  timestamps: true,
  modelName: 'User',
  tableName: 'users',
  sequelize: sequelizeConnection,
})

export default User

`
