export const userRoutes = `
import { Router, Request, Response } from 'express';
import * as userController from '../controllers/user';
import { CreateUserDTO, UpdateUserDTO } from '../../db/dto/user.dto';

const usersRouter = Router();

usersRouter.get('/', async (_req: Request, res: Response) => {
  const results = await userController.getAll();

  return res.status(200).json(results);
});

usersRouter.get('/:id', async (req: Request, res: Response) => {
  const id = Number(req.params.id);
  const result = await userController.getById(id);

  return res.status(200).json(result);
});

usersRouter.put('/:id', async (req: Request, res: Response) => {
  const id = Number(req.params.id);
  const payload: UpdateUserDTO = req.body;
  const result = await userController.update(id, payload);

  return res.status(201).json(result);
});

usersRouter.delete('/:id', async (req: Request, res: Response) => {
  const id = Number(req.params.id);
  const result = await userController.deleteById(id);

  return res.status(204).json({ success: result });
});

usersRouter.post('/', async (req: Request, res: Response) => {
  const payload: CreateUserDTO = req.body;
  const result = await userController.create(payload);

  return res.status(200).json(result);
});

export default usersRouter;

`

export const indexRouter = `
import { Router } from 'express';
import UsersRouter from './users.routes';

const router = Router();

router.use('/users', UsersRouter);

export default router;
`
