import { join } from 'path';
import { unlinkSync } from 'fs';
import { assert } from 'chai';
import { writeFile } from '../../src/utils';

describe('@WriteFile', () => {
  it('Deve escrever um texto no arquivo com sucesso', async () => {
    const filePath = join(__dirname, 'test-file.txt');

    after((done) => {
      unlinkSync(filePath);
      done();
    });

    const response = await writeFile.execute({
      directory_name: join(__dirname),
      filename: 'test-file.txt',
      text: 'felipe neves',
    });

    assert.equal(response, undefined);
  });

  it('Deve escrever mais de um texto no arquivo com sucesso', async () => {
    const filePath = [
      join(__dirname, 'test-file-1.txt'),
      join(__dirname, 'test-file-2.txt'),
    ];

    after((done) => {
      filePath.forEach((file) => unlinkSync(file));
      done();
    });

    const response = await writeFile.execute({
      directory_name: join(__dirname),
      filename: ['test-file-1.txt', 'test-file-2.txt'],
      text: ['Felipe Neves', 'Davi Neves'],
    });

    assert.equal(response, undefined);
  });

  it('Deve escrever com sucesso quando for um objeto json', async () => {
    const filePath = join(__dirname, 'test-file-json.txt');

    after((done) => {
      unlinkSync(filePath);
      done();
    });

    const response = await writeFile.execute({
      directory_name: join(__dirname),
      filename: 'test-file-json.txt',
      text: '',
      formate: true,
      json: { name: 'felipe neves' }
    });

    assert.equal(response, undefined);
  })
});
